<?php

namespace Redis\Db0;


class SessionRedisModel extends \Redis\Db0\AbstractModel {

    static $prefix = "";


    protected $_tableName = 'PHPREDIS_SESSION';

   
    public function calcKey($id) {
        return $this->_tableName . self::DELIMITER . $id;
    }


    public function find($id) {
        $result = $this->get($this->calcKey($id));

        if ($result) {
            return json_decode($result, true);
        }
        return null;
    }

   

    public function update($id, $data) {
        return $this->set($this->calcKey($id), json_encode($data));
    }

    public function tableHSet($h,$key,$val,$experio=0){
        return $this->hset($this->calcKey($h),$key,$val,$experio);
    }

    public function tableHGet($h,$key){
        return $this->hget($this->calcKey($h),$key);
    }

    public function tableHMSet($h,$keysvalue,$experio=0){
        return $this->hmset($this->calcKey($h),$keysvalue,$experio);
    }

    public function tableHMGet($h,$keyvalues){
        return $this->tableHMGet($this->calcKey($h),$keyvalues);
    }


    public function tableDel($h){
        return $this->del($this->calcKey($h));
    }

    public function delSessionKey($key){
        //\Our\Log::getInstance()->write($this->calcKey($key));
        $key=trim($key);
        return $this->getRedis()->del($this->calcKey($key));

    }
    public function delSessionKeyTest($key){
        \Our\Log::getInstance()->write($this->calcKey($key));       
        $redisObject=$this->getRedis();
	$deleteKey=$this->calcKey($key);	
        $res=$redisObject->del($deleteKey);
        var_dump($res);
	session_unset();
        session_destroy();
	exit;

    }
    public function getSessionKey($key){
        return $this->getRedis()->get($this->calcKey($key));
    }

    public function tableCacheGet($id){
        $result = $this->get($this->calcKey($id));
        return $result;
    }
    public function tableCacheSet($id,$data,$experio){
        $res=$this->set($this->calcKey($id), $data,$experio);
        return $res;
    }

    private static $_instance = null;


    public static function getInstance() {
        if (!(self::$_instance instanceof self)) {
            self::$_instance = new self();
        }

        return self::$_instance;
    }

}
